ToolVisibility

Enum ToolVisibility 

pub enum ToolVisibility {
    Read,
    Write,
    Dangerous,
    System,
    Hidden,
}

Variants



Read



Write



Dangerous



System



Hidden

Hidden from Request::ToolList discover responses, but still reachable by id via Request::ToolSchema (describe) and Request::RunTool (call). Use for tools that exist for integration tests, debugging, or advanced humans, but would add noise to an LLM’s catalog.